@@ -1,8 +1,8 @@
 use super::MJHead;
 use crate::helper::sort::sort_by_key;
+use crate::prelude::hash::Map;
 use crate::prelude::render::{Error, Header, Options, Render, Renderable};
 use std::cell::{Ref, RefCell};
-use std::collections::HashMap;
 use std::rc::Rc;
 
 fn google_font(name: &str) -> String {
@@ -45,11 +45,11 @@ p { display: block; margin: 13px 0; }
 "#;
 
 impl MJHead {
-    pub fn build_attributes_all(&self) -> HashMap<&str, &str> {
+    pub fn build_attributes_all(&self) -> Map<&str, &str> {
         self.children
             .iter()
             .filter_map(|item| item.as_mj_attributes())
-            .fold(HashMap::<&str, &str>::new(), |result, attrs| {
+            .fold(Map::<&str, &str>::new(), |result, attrs| {
                 attrs
                     .children()
                     .iter()
@@ -65,60 +65,54 @@ impl MJHead {
             })
     }
 
-    pub fn build_attributes_class(&self) -> HashMap<&str, HashMap<&str, &str>> {
+    pub fn build_attributes_class(&self) -> Map<&str, Map<&str, &str>> {
         self.children
             .iter()
             .filter_map(|item| item.as_mj_attributes())
-            .fold(
-                HashMap::<&str, HashMap<&str, &str>>::new(),
-                |result, attrs| {
-                    attrs
-                        .children()
-                        .iter()
-                        .filter_map(|item| item.as_mj_class())
-                        .fold(result, |mut res, class| {
-                            (*res.entry(class.name()).or_insert_with(HashMap::new)).extend(
-                                class
-                                    .attributes()
-                                    .iter()
-                                    .map(|(k, v)| (k.as_str(), v.as_str())),
-                            );
-                            res
-                        })
-                },
-            )
+            .fold(Map::<&str, Map<&str, &str>>::new(), |result, attrs| {
+                attrs
+                    .children()
+                    .iter()
+                    .filter_map(|item| item.as_mj_class())
+                    .fold(result, |mut res, class| {
+                        (*res.entry(class.name()).or_insert_with(Map::new)).extend(
+                            class
+                                .attributes()
+                                .iter()
+                                .map(|(k, v)| (k.as_str(), v.as_str())),
+                        );
+                        res
+                    })
+            })
     }
 
-    pub fn build_attributes_element(&self) -> HashMap<&str, HashMap<&str, &str>> {
+    pub fn build_attributes_element(&self) -> Map<&str, Map<&str, &str>> {
         self.children
             .iter()
             .filter_map(|item| item.as_mj_attributes())
-            .fold(
-                HashMap::<&str, HashMap<&str, &str>>::new(),
-                |result, attrs| {
-                    attrs
-                        .children()
-                        .iter()
-                        .filter_map(|item| item.as_element())
-                        .fold(result, |mut res, element| {
-                            (*res.entry(element.name()).or_insert_with(HashMap::new)).extend(
-                                element
-                                    .attributes()
-                                    .iter()
-                                    .map(|(k, v)| (k.as_str(), v.as_str())),
-                            );
-                            res
-                        })
-                },
-            )
+            .fold(Map::<&str, Map<&str, &str>>::new(), |result, attrs| {
+                attrs
+                    .children()
+                    .iter()
+                    .filter_map(|item| item.as_element())
+                    .fold(result, |mut res, element| {
+                        (*res.entry(element.name()).or_insert_with(Map::new)).extend(
+                            element
+                                .attributes()
+                                .iter()
+                                .map(|(k, v)| (k.as_str(), v.as_str())),
+                        );
+                        res
+                    })
+            })
     }
 
-    pub fn build_font_families(&self) -> HashMap<&str, &str> {
+    pub fn build_font_families(&self) -> Map<&str, &str> {
         self.children
             .iter()
             .filter_map(|item| item.as_mj_font())
             .map(|item| (item.name(), item.href()))
-            .collect::<HashMap<&str, &str>>()
+            .collect::<Map<&str, &str>>()
     }
 }
 
@@ -260,6 +254,21 @@ impl<'e, 'h> MJHeadRender<'e, 'h> {
             .trim()
             .to_string()
     }
+
+    fn render_raw(&self, opts: &Options) -> Result<String, Error> {
+        let siblings = self.element.children.len();
+        self.element
+            .children
+            .iter()
+            .filter_map(|child| child.as_mj_raw())
+            .enumerate()
+            .try_fold(String::default(), |res, (index, child)| {
+                let mut renderer = child.renderer(Rc::clone(&self.header));
+                renderer.set_index(index);
+                renderer.set_siblings(siblings);
+                Ok(res + &renderer.render(opts)?)
+            })
+    }
 }
 
 impl<'e, 'h> Render<'h> for MJHeadRender<'e, 'h> {
@@ -267,7 +276,7 @@ impl<'e, 'h> Render<'h> for MJHeadRender<'e, 'h> {
         self.header.borrow()
     }
 
-    fn render(&self, _opts: &Options) -> Result<String, Error> {
+    fn render(&self, opts: &Options) -> Result<String, Error> {
         let mut buf = String::from("<head>");
         // we write the title even though there is no content
         buf.push_str("<title>");
@@ -287,6 +296,7 @@ impl<'e, 'h> Render<'h> for MJHeadRender<'e, 'h> {
         buf.push_str(&self.render_font_families());
         buf.push_str(&self.render_media_queries());
         buf.push_str(&self.render_styles());
+        buf.push_str(&self.render_raw(opts)?);
         buf.push_str("</head>");
         Ok(buf)
     }
