@@ -2,9 +2,9 @@ use super::{MJNavbarLink, MJNavbarLinkChild, NAME};
 use crate::helper::condition::conditional_tag;
 use crate::helper::size::Pixel;
 use crate::helper::tag::Tag;
+use crate::prelude::hash::Map;
 use crate::prelude::render::{Error, Header, Options, Render, Renderable};
 use std::cell::{Ref, RefCell};
-use std::collections::HashMap;
 use std::rc::Rc;
 
 impl<'r, 'e: 'r, 'h: 'r> Renderable<'r, 'e, 'h> for MJNavbarLinkChild {
@@ -19,7 +19,7 @@ impl<'r, 'e: 'r, 'h: 'r> Renderable<'r, 'e, 'h> for MJNavbarLinkChild {
 struct MJNavbarLinkRender<'e, 'h> {
     header: Rc<RefCell<Header<'h>>>,
     element: &'e MJNavbarLink,
-    extra: HashMap<String, String>,
+    extra: Map<String, String>,
     container_width: Option<Pixel>,
 }
 
@@ -99,11 +99,11 @@ impl<'e, 'h> Render<'h> for MJNavbarLinkRender<'e, 'h> {
         self.extra.insert(key.to_string(), value.to_string());
     }
 
-    fn extra_attributes(&self) -> Option<&HashMap<String, String>> {
+    fn extra_attributes(&self) -> Option<&Map<String, String>> {
         Some(&self.extra)
     }
 
-    fn attributes(&self) -> Option<&HashMap<String, String>> {
+    fn attributes(&self) -> Option<&Map<String, String>> {
         Some(&self.element.attributes)
     }
 
@@ -136,7 +136,7 @@ impl<'r, 'e: 'r, 'h: 'r> Renderable<'r, 'e, 'h> for MJNavbarLink {
         Box::new(MJNavbarLinkRender::<'e, 'h> {
             element: self,
             header,
-            extra: HashMap::new(),
+            extra: Map::new(),
             container_width: None,
         })
     }
