@@ -2,9 +2,9 @@ use super::{MJSocial, MJSocialChild, NAME};
 use crate::helper::condition::conditional_tag;
 use crate::helper::size::{Pixel, Size};
 use crate::helper::tag::Tag;
+use crate::prelude::hash::Map;
 use crate::prelude::render::{Error, Header, Options, Render, Renderable};
 use std::cell::{Ref, RefCell};
-use std::collections::HashMap;
 use std::rc::Rc;
 
 impl<'r, 'e: 'r, 'h: 'r> Renderable<'r, 'e, 'h> for MJSocialChild {
@@ -71,11 +71,7 @@ impl<'e, 'h> MJSocialRender<'e, 'h> {
             .iter()
             .zip(EXTRA_CHILD_KEY.iter())
             .filter_map(|(con_key, child_key)| {
-                if let Some(value) = self.attribute(con_key) {
-                    Some((*child_key, value))
-                } else {
-                    None
-                }
+                self.attribute(con_key).map(|value| (*child_key, value))
             })
             .collect::<Vec<_>>()
     }
@@ -97,7 +93,7 @@ impl<'e, 'h> MJSocialRender<'e, 'h> {
                 let mut renderer = child.renderer(Rc::clone(&self.header));
                 renderer.set_index(index);
                 child_attributes.iter().for_each(|(key, value)| {
-                    renderer.add_extra_attribute(key, &value);
+                    renderer.add_extra_attribute(key, value);
                 });
                 Ok(res
                     + &conditional_tag(td.open())
@@ -117,7 +113,7 @@ impl<'e, 'h> MJSocialRender<'e, 'h> {
                 let mut renderer = child.renderer(Rc::clone(&self.header));
                 renderer.set_index(index);
                 child_attributes.iter().for_each(|(key, value)| {
-                    renderer.add_extra_attribute(key, &value);
+                    renderer.add_extra_attribute(key, value);
                 });
                 Ok(res + &renderer.render(opts)?)
             },
@@ -143,7 +139,7 @@ impl<'e, 'h> Render<'h> for MJSocialRender<'e, 'h> {
         }
     }
 
-    fn attributes(&self) -> Option<&HashMap<String, String>> {
+    fn attributes(&self) -> Option<&Map<String, String>> {
         Some(&self.element.attributes)
     }
 
