@@ -3,9 +3,9 @@ use crate::helper::condition::{conditional_tag, END_CONDITIONAL_TAG, START_CONDI
 use crate::helper::size::Pixel;
 use crate::helper::tag::Tag;
 use crate::mj_section::WithMJSectionBackground;
+use crate::prelude::hash::Map;
 use crate::prelude::render::{Error, Header, Options, Render, Renderable};
 use std::cell::{Ref, RefCell};
-use std::collections::HashMap;
 use std::rc::Rc;
 
 struct MJWrapperRender<'e, 'h> {
@@ -262,7 +262,7 @@ impl<'e, 'h> Render<'h> for MJWrapperRender<'e, 'h> {
         }
     }
 
-    fn attributes(&self) -> Option<&HashMap<String, String>> {
+    fn attributes(&self) -> Option<&Map<String, String>> {
         Some(&self.element.attributes)
     }
 
